package testing;

import java.util.Collection;
import java.util.HashSet;
import java.util.Iterator;
import java.util.logging.Level;

import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JSplitPane;

import edu.stanford.smi.protege.model.Frame;
import edu.stanford.smi.protege.util.CollectionUtilities;
import edu.stanford.smi.protege.util.ComponentFactory;
import edu.stanford.smi.protege.util.Log;
import edu.stanford.smi.protege.widget.AbstractTabWidget;
import edu.stanford.smi.protegex.owl.ProtegeOWL;
import edu.stanford.smi.protegex.owl.model.OWLModel;
import edu.stanford.smi.protegex.owl.ui.dialogs.SelectClassPanel;

public class TwoClassTreesTab extends AbstractTabWidget {

	public void initialize() {
		setLabel("TwoClassTreesTab");
		
		OWLModel owlModel1 = loadOwlModel("http://www.co-ode.org/ontologies/pizza/2007/02/12/pizza.owl");
		OWLModel owlModel2 = loadOwlModel("http://protege.cim3.net/file/pub/ontologies/koala/koala.owl");
		
		JSplitPane mainPane = ComponentFactory.createLeftRightSplitPane();
		mainPane.setLeftComponent(getClsesPanel(owlModel1));
		mainPane.setRightComponent(getClsesPanel(owlModel2));
		
		add(mainPane);

	}
	
	
	private JComponent getClsesPanel(OWLModel owlModel) {
		if (owlModel == null) {
			return new JPanel();
		}
		Collection rootClasses = CollectionUtilities.createCollection(owlModel.getOWLThingClass());
		makeSystemClassesHidden(owlModel);
		
		return new SelectClassPanel(owlModel, rootClasses, false, true);		
	}
	
	
	private OWLModel loadOwlModel(String uri) {
		OWLModel owlModel = null;
		try {
			owlModel = ProtegeOWL.createJenaOWLModelFromURI(uri);
		} catch (Exception e) {
			Log.getLogger().log(Level.WARNING, "Error at loading ontology from: " + uri, e);
		}
		
		return owlModel;
	}
	
	
	@SuppressWarnings({"deprecation" })
	private void makeSystemClassesHidden(OWLModel owlModel) {
		Collection systemFrames = new HashSet(owlModel.getSystemFrames().getFrames());
		systemFrames.addAll(owlModel.getOWLSystemResources());
		
		for (Iterator iterator = systemFrames.iterator(); iterator.hasNext();) {
			Frame frame = (Frame) iterator.next();
			frame.setVisible(false);
		}
		owlModel.getOWLThingClass().setVisible(true);
		owlModel.getProject().setDisplayHiddenClasses(false);
		
	}
	

}
